mocks

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 17, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CredentialStoreMock

type CredentialStoreMock struct {
	mock.Mock
}

CredentialStoreMock is an autogenerated mock type for the CredentialStore type

func NewCredentialStoreMock

func NewCredentialStoreMock(t interface {
	mock.TestingT
	Cleanup(func())
}) *CredentialStoreMock

NewCredentialStoreMock creates a new instance of CredentialStoreMock. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*CredentialStoreMock) Clear

func (_mock *CredentialStoreMock) Clear() error

Clear provides a mock function for the type CredentialStoreMock

func (*CredentialStoreMock) Close

func (_mock *CredentialStoreMock) Close() error

Close provides a mock function for the type CredentialStoreMock

func (*CredentialStoreMock) EXPECT

func (*CredentialStoreMock) SaveAPIKeyCredential

func (_mock *CredentialStoreMock) SaveAPIKeyCredential(apiKey string, tenantDomain string) error

SaveAPIKeyCredential provides a mock function for the type CredentialStoreMock

func (*CredentialStoreMock) SaveTokenCredential

func (_mock *CredentialStoreMock) SaveTokenCredential(token string, refreshToken string, tenantDomain string) error

SaveTokenCredential provides a mock function for the type CredentialStoreMock

type CredentialStoreMock_Clear_Call

type CredentialStoreMock_Clear_Call struct {
	*mock.Call
}

CredentialStoreMock_Clear_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Clear'

func (*CredentialStoreMock_Clear_Call) Return

func (*CredentialStoreMock_Clear_Call) Run

func (*CredentialStoreMock_Clear_Call) RunAndReturn

type CredentialStoreMock_Close_Call

type CredentialStoreMock_Close_Call struct {
	*mock.Call
}

CredentialStoreMock_Close_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Close'

func (*CredentialStoreMock_Close_Call) Return

func (*CredentialStoreMock_Close_Call) Run

func (*CredentialStoreMock_Close_Call) RunAndReturn

type CredentialStoreMock_Expecter

type CredentialStoreMock_Expecter struct {
	// contains filtered or unexported fields
}

func (*CredentialStoreMock_Expecter) Clear

Clear is a helper method to define mock.On call

func (*CredentialStoreMock_Expecter) Close

Close is a helper method to define mock.On call

func (*CredentialStoreMock_Expecter) SaveAPIKeyCredential

func (_e *CredentialStoreMock_Expecter) SaveAPIKeyCredential(apiKey interface{}, tenantDomain interface{}) *CredentialStoreMock_SaveAPIKeyCredential_Call

SaveAPIKeyCredential is a helper method to define mock.On call

  • apiKey string
  • tenantDomain string

func (*CredentialStoreMock_Expecter) SaveTokenCredential

func (_e *CredentialStoreMock_Expecter) SaveTokenCredential(token interface{}, refreshToken interface{}, tenantDomain interface{}) *CredentialStoreMock_SaveTokenCredential_Call

SaveTokenCredential is a helper method to define mock.On call

  • token string
  • refreshToken string
  • tenantDomain string

type CredentialStoreMock_SaveAPIKeyCredential_Call

type CredentialStoreMock_SaveAPIKeyCredential_Call struct {
	*mock.Call
}

CredentialStoreMock_SaveAPIKeyCredential_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SaveAPIKeyCredential'

func (*CredentialStoreMock_SaveAPIKeyCredential_Call) Return

func (*CredentialStoreMock_SaveAPIKeyCredential_Call) Run

func (*CredentialStoreMock_SaveAPIKeyCredential_Call) RunAndReturn

type CredentialStoreMock_SaveTokenCredential_Call

type CredentialStoreMock_SaveTokenCredential_Call struct {
	*mock.Call
}

CredentialStoreMock_SaveTokenCredential_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SaveTokenCredential'

func (*CredentialStoreMock_SaveTokenCredential_Call) Return

func (*CredentialStoreMock_SaveTokenCredential_Call) Run

func (*CredentialStoreMock_SaveTokenCredential_Call) RunAndReturn

func (_c *CredentialStoreMock_SaveTokenCredential_Call) RunAndReturn(run func(token string, refreshToken string, tenantDomain string) error) *CredentialStoreMock_SaveTokenCredential_Call

Jump to